using System;
using Microsoft.SharePoint;
using System.Diagnostics;


namespace Microsoft.IW
{
	public class MySiteCreate : SPFeatureReceiver
	{

        /// <summary>
        /// Occurs after a Feature is activated.
        /// </summary>
        /// <param name="properties">An <see cref="T:Microsoft.SharePoint.SPFeatureReceiverProperties"></see> object that represents the properties of the event.</param>
		public override void FeatureActivated(SPFeatureReceiverProperties properties)
		{
			try
			{
                //look at the properties collection to get the new master page name
                string newMaster = properties.Feature.Properties["MasterName"].Value;

                ReplaceMasterPage(newMaster, "default.master", properties);
            }
			catch (Exception ex)
			{
				//try writing to event log
				UpdateLog("Error in handler: " + ex.Message, EventLogEntryType.Error);
			}
		}



        /// <summary>
        /// Occurs when a Feature is deactivated.
        /// </summary>
        /// <param name="properties">An <see cref="T:Microsoft.SharePoint.SPFeatureReceiverProperties"></see> object that represents the properties of the event.</param>
		public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
		{
            try
            {
                UpdateLog("Deactiving Feature and resetting master url property.", EventLogEntryType.Information);

                //look at the properties collection to get the new master page name
                string oldMaster = properties.Feature.Properties["MasterName"].Value;

                ReplaceMasterPage("default.master", oldMaster, properties);
            }
            catch (Exception ex)
            {
                //try writing to event log
                UpdateLog("Error in handler: " + ex.Message, EventLogEntryType.Error);
            }
        }



        /// <summary>
        /// Occurs after a Feature is installed.
        /// </summary>
        /// <param name="properties">An <see cref="T:Microsoft.SharePoint.SPFeatureReceiverProperties"></see> object that represents the properties of the event.</param>
	    public override void FeatureInstalled(SPFeatureReceiverProperties properties)
		{
			//throw new Exception("The method or operation is not implemented.");
		}

        /// <summary>
        /// Occurs when a Feature is uninstalled.
        /// </summary>
        /// <param name="properties">An <see cref="T:Microsoft.SharePoint.SPFeatureReceiverProperties"></see> object that represents the properties of the event.</param>
		public override void FeatureUninstalling(SPFeatureReceiverProperties properties)
		{
			//throw new Exception("The method or operation is not implemented.");
		}

        /// <summary>
        /// Replaces the master page.
        /// </summary>
        /// <param name="newMaster">The new master.</param>
        /// <param name="oldMaster">The old master.</param>
        /// <param name="properties">The properties.</param>
        private static void ReplaceMasterPage(string newMaster, string oldMaster, SPFeatureReceiverProperties properties)
        {
            if (!string.IsNullOrEmpty(newMaster) && !string.IsNullOrEmpty(oldMaster))
            {
                using (SPWeb curWeb = (SPWeb)properties.Feature.Parent)
                {
                    if (curWeb.WebTemplate != "SPSPERS")
                        return;

                    //got the current site and root web in site, now set the master Url
                    //to our master page that should have been uploaded as part 
                    //of our feature
                    if (curWeb.MasterUrl.Contains(oldMaster))
                    {
                        curWeb.MasterUrl = curWeb.MasterUrl.Replace(oldMaster, newMaster);
                        curWeb.Update();
                        UpdateLog("MasterUrl property updated for web " + curWeb.Title + " and set to " + newMaster,
                                  EventLogEntryType.Information);
                    }
                }
            }
        }

        /// <summary>
        /// Updates the log.
        /// </summary>
        /// <param name="Message">The message.</param>
        /// <param name="msgType">Type of the MSG.</param>
        private static void UpdateLog(string Message, EventLogEntryType msgType)
        {
            try
            {
                EventLog.WriteEntry("My Site Created Handler", Message, msgType);
            }
            catch
            {
                //ignore
            }
        }
	}
}
